#!/bin/sh
#
# Patch: Tivoli SecureWay User Administration 3.8 Patch 2
#
# Description: This patch fixes an installation problem when
# A TMR has had it's Language Pack installaed and the TMR server
# is not running in the C locale.
#
# This patch can not change the contents of the cdrom, however it
# does contain a subset of the filepacks contained on the cdrom 
# that have been fixed to avoid this problem.
#
# Usage: From within the patch directory run this script with
# two arguments:
#
#  1) Full path to the top level cdrom directory.
#  2) Full patch to where you want the fixed installation
#     image to be placed. Note: You should make sure that
#     there is enough room for the installation image to be
#     copied.
#
#  Once this script has finished, you can then install the 
# product as normal, from the new installation directory.
#
#
#

# first check the number of args supplied...
if [ $# -ne 2 ]; then
  echo "Usage: 38ADM02.sh [cdrom-source-path] [destination-path]";
  exit 1;
fi

# Now lets check the various permutations of arguments to make sure
# that directories exist as needed.
if [ ! -d $1 ]; then
  echo "Usage: 38ADM02.sh [cdrom-source-path] [destination-path]";
  echo "	$1 is not a directory or does not exist!";
  exit 1;
fi

if [ ! -d $2 ]; then
  echo "Usage: 38ADM02.sh [cdrom-source-path] [destination-path]";
  echo "	$2 is not a directory or does not exist!";
  exit 1;
fi

if [ ! -d $1/3.8-ADM ]; then
  echo "Usage: 38ADM02.sh [cdrom-source-path] [destination-path]";
  echo "	$1 is not the top level of the User Administration cdrom!";
  exit 1;
fi

# Now check to see if the tar file with our filepacks is in our current
# directory.....

if [ ! -f 38ADM02_inst.tar ]; then
  echo "The 38ADM02_inst.tar file is not in my current working directory!";
  exit 1;
fi

# Ok, everything checks out...

# Lets copy the cdrom contents..
echo "Copying cdrom contents......";
cp -r $1/3.8-ADM $2;

echo "Removing bad file packs....";
cwd=`pwd`;
cd $2/3.8-ADM;
rm -f FILE10.PKT FILE11.PKT FILE12.PKT FILE13.PKT FILE32.PKT FILE33.PKT FILE34.PKT FILE35.PKT

echo "Patching the installation image.....";
tar -xf $cwd/38ADM02_inst.tar;
if [ $? -ne 0 ]; then
  echo "Something is wrong with the 38ADM02_inst.tar file!";
  echo "You should contact support, or try to download the patch again.";
  exit 1;
fi

echo "Done!";

cd $cwd;
echo "You can now perform a normal installation.";
